coef.barma: Extract Coefficients from a barma Model

View source: R/coef.barma.R

coef.barmaR Documentation

Extract Coefficients from a barma Model

Description

S3 method for extracting the vector of estimated coefficients from a fitted model object of class '"barma"'.

Usage

## S3 method for class 'barma'
coef(object, ...)

Arguments

object

A fitted model object of class '"barma"'.

...

Additional arguments (currently ignored).

Value

A named numeric vector of all estimated coefficients (e.g., alpha, varphi, theta, phi).


betaARMA documentation built on March 29, 2026, 5:08 p.m.