fitted.barma: Extract Fitted Values from a barma Model

View source: R/fitted.barma.R

fitted.barmaR Documentation

Extract Fitted Values from a barma Model

Description

S3 method for extracting the fitted mean values (mu-hat) from a fitted model object of class '"barma"'.

Usage

## S3 method for class 'barma'
fitted(object, ...)

Arguments

object

A fitted model object of class '"barma"'.

...

Additional arguments (currently ignored).

Details

The fitted values are returned as a time series ('ts') object, matching the time properties of the original input 'y'. The first 'max_lag' observations are 'NA', as they cannot be fitted.

Value

A 'ts' object of the fitted mean values.


betaARMA documentation built on March 29, 2026, 5:08 p.m.