forecast.barma: Forecast a barma Model

View source: R/forecast.barma.R

forecast.barmaR Documentation

Forecast a barma Model

Description

S3 method for producing forecasts from a fitted 'barma' model object.

Usage

## S3 method for class 'barma'
forecast(object, h = 6, xreg = NULL, ...)

Arguments

object

A fitted model object of class 'barma'. Must contain 'object$xreg' if regressors were used.

h

The number of steps to forecast ahead (forecast horizon). Default is 6.

xreg

A matrix of future regressor values for the forecast horizon. Should have h rows and the same number of columns as xreg used in model fitting.

...

Additional arguments (currently ignored).

Details

This function computes dynamic, multi-step-ahead point forecasts. It implements a "Regression with ARMA errors" logic, where the AR components are applied to the deviations from the regression line: AR(g(y_{t-k}) - x_{t-k}^\top \beta).

Value

A 'ts' object containing the point forecasts for h steps ahead.


betaARMA documentation built on March 29, 2026, 5:08 p.m.