View source: R/print.summary.barma.R
| print.summary.barma | R Documentation |
S3 method for printing the detailed summary of a '"barma"' model object.
## S3 method for class 'summary.barma'
print(x, ...)
x |
A fitted model summary object of class '"summary.barma"'. |
... |
Additional arguments (currently ignored). |
This function formats and displays the summary list created by 'summary.barma()', including the call, coefficient table, and information criteria.
Invisibly returns the original object 'x'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.