| coef.barma | R Documentation |
S3 method for extracting the vector of estimated coefficients from a fitted model object of class '"barma"'.
## S3 method for class 'barma'
coef(object, ...)
object |
A fitted model object of class '"barma"'. |
... |
Additional arguments (currently ignored). |
A named numeric vector of all estimated coefficients (e.g., alpha, varphi, theta, phi).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.