| ._get_phi_start | R Documentation |
Calculates the initial value for the precision parameter phi based on the residuals of an initial 'lm.fit' object, following Ferrari & Cribari-Neto (2004).
This helper uses the *exact* mathematical logic from the original 'start_values.R' file to ensure identical numerical output.
._get_phi_start(fit, n_eff, linkinv, mu.eta)
fit |
An 'lm.fit' object. |
n_eff |
The effective number of observations used in the fit. |
linkinv |
The inverse link function. |
mu.eta |
The derivative of the mean w.r.t. eta (d(mu)/d(eta)). |
A single numeric value for phi_start.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.