| fitted.barma | R Documentation |
S3 method for extracting the fitted mean values (mu-hat) from a fitted model object of class '"barma"'.
## S3 method for class 'barma'
fitted(object, ...)
object |
A fitted model object of class '"barma"'. |
... |
Additional arguments (currently ignored). |
The fitted values are returned as a time series ('ts') object, matching the time properties of the original input 'y'. The first 'max_lag' observations are 'NA', as they cannot be fitted.
A 'ts' object of the fitted mean values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.