| print.barma | R Documentation |
S3 method for printing a summary of a fitted '"barma"' model object.
## S3 method for class 'barma'
print(x, ...)
x |
A fitted model object of class '"barma"'. |
... |
Additional arguments (currently ignored). |
This function provides a concise summary, showing the function call that generated the model, the link function used, and the final estimated coefficients.
Invisibly returns the original object 'x'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.